# def monkeypatch_setattr(target, name, value=notset, raising=True):


# def monkeypatch_delattr(target, name=notset, raising=True):


# def monkeypatch_setitem(self, dic, name, value):


# def monkeypatch_delitem(obj, name, raising=True):


# def monkeypatch_setenv(name, value, prepend=False):


# def monkeypatch_delenv(name, value, raising=True):


# def monkeypatch_syspath_prepend(path):


# def monkeypatch_chdir(path):
